@@ -77,10 +77,6 @@ class VecValDer(np.lib.mixins.NDArrayOperatorsMixin):
             self.val[key] = value.val
             self.der[key] = value.der
         else:
-            # We're being passed a scalar? Or something weird?
-            # Like vec[:] = other_vec?
-            value = np.asarray(value)
-            assert self.val[key].shape == value.shape
             self.val[key] = value
             self.der[key] = true_np.zeros(self.der[key].shape)
 
